from .base import ObjectListModel, BaseModel

class AccountList(ObjectListModel):

    def __init__(self):
        super().__init__(list=[], listObject=Account)

class Account(BaseModel):

    def __init__(self,
        ID=None,
        Accountant=None,
        AccountManager=None,
        AccountManagerFullName=None,
        AccountManagerHID=None,
        ActivitySector=None,
        ActivitySubSector=None,
        AddressLine1=None,
        AddressLine2=None,
        AddressLine3=None,
        BankAccounts=None,
        Blocked=None,
        BSN=None,
        BusinessType=None,
        CanDropShip=None,
        ChamberOfCommerce=None,
        City=None,
        Classification1=None,
        Classification2=None,
        Classification3=None,
        Classification4=None,
        Classification5=None,
        Classification6=None,
        Classification7=None,
        Classification8=None,
        Code=None,
        CodeAtSupplier=None,
        CompanySize=None,
        ConsolidationScenario=None,
        ControlledDate=None,
        Country=None,
        CountryName=None,
        Created=None,
        Creator=None,
        CreatorFullName=None,
        CreditLinePurchase=None,
        CreditLineSales=None,
        DatevCreditorCode=None,
        DatevDebtorCode=None,
        DiscountPurchase=None,
        DiscountSales=None,
        Division=None,
        Email=None,
        EndDate=None,
        EstablishedDate=None,
        Fax=None,
        GLAccountPurchase=None,
        GLAccountSales=None,
        GLAP=None,
        GLAR=None,
        GlnNumber=None,
        HasWithholdingTaxSales=None,
        ignoreDatevWarningMessage=None,
        IntraStatArea=None,
        IntraStatDeliveryTerm=None,
        IntraStatTransactionA=None,
        IntraStatTractionB=None,
        IntraStatTransporterMethod=None,
        InvoiceAccount=None,
        InvoiceAccountCode=None,
        InvoiceAccountName=None,
        InvoiceAttachmentType=None,
        InvoicingMethod=None,
        IsAccountant=None,
        IsAgency=None,
        IsAnonymised=None,
        IsCompetitor=None,
        IsExtraDuty=None,
        IsMailing=None,
        IsPilot=None,
        IsReseller=None,
        IsSales=None,
        IsSupplier=None,
        Language=None,
        LanguageDescription=None,
        Latitude=None,
        LeadPurpose=None,
        LeadSource=None,
        Logo=None,
        LogoFileName=None,
        LogoThumbnailUrl=None,
        LogoUrl=None,
        Longitude=None,
        MainContact=None,
        Modified=None,
        Modifier=None,
        ModifierFullName=None,
        Name=None,
        OINNumber=None,
        Parent=None,
        PayAsYouEarn=None,
        PaymentConditionPurchase=None,
        PaymentConditionPurchaseDescription=None,
        PaymentConditionSales=None,
        PaymentConditionSalesDescription=None,
        Phone=None,
        PhoneExtension=None,
        Postcode=None,
        PriceList=None,
        PurchaseCurrency=None,
        PurchaseCurrencyDescription=None,
        PurchaseLeadDays=None,
        PurchaseVATCode=None,
        PurchaseVATCodeDescription=None,
        RecepientOfCommissions=None,
        Remarks=None,
        Reseller=None,
        ResellerCode=None,
        ResellerName=None,
        RSIN=None,
        SalesCurrency=None,
        SalesCurrencyDescription=None,
        SalesVATCode=None,
        SalesVATCodeDescription=None,
        SearchCode=None,
        SecurityLevel=None,
        SeperateInvPerSubscription=None,
        ShippingLeadDays=None,
        ShippingMethod=None,
        ShowRemarkForSales=None,
        StartDate=None,
        State=None,
        StateName=None,
        Status=None,
        StatusSince=None,
        TradeName=None,
        Type=None,
        UniqueTaxpayerReference=None,
        VATLiability=None,
        VATNumber=None,
        Website=None
    ):

        super().__init__()

        self.ID = ID
        self.Accountant = Accountant
        self.AccountManager = AccountManager
        self.AccountManagerFullName = AccountManagerFullName
        self.AccountManagerHID = AccountManagerHID
        self.ActivitySector = ActivitySector
        self.ActivitySubSector = ActivitySubSector
        self.AddressLine1 = AddressLine1
        self.AddressLine2 = AddressLine2
        self.AddressLine3 = AddressLine3
        self.BankAccounts = BankAccounts
        self.Blocked = Blocked
        self.BSN = BSN
        self.BusinessType = BusinessType
        self.CanDropShip = CanDropShip
        self.ChamberOfCommerce = ChamberOfCommerce
        self.City = City
        self.Classification1 = Classification1
        self.Classification2 = Classification2
        self.Classification3 = Classification3
        self.Classification4 = Classification4
        self.Classification5 = Classification5
        self.Classification6 = Classification6
        self.Classification7 = Classification7
        self.Classification8 = Classification8
        self.Code = Code
        self.CodeAtSupplier = CodeAtSupplier
        self.CompanySize = CompanySize
        self.ConsolidationScenario = ConsolidationScenario
        self.ControlledDate = ControlledDate
        self.Country = Country
        self.CountryName = CountryName
        self.Created = Created
        self.Creator = Creator
        self.CreatorFullName = CreatorFullName
        self.CreditLinePurchase = CreditLinePurchase
        self.CreditLineSales = CreditLineSales
        self.DatevCreditorCode = DatevCreditorCode
        self.DatevDebtorCode = DatevDebtorCode
        self.DiscountPurchase = DiscountPurchase
        self.DiscountSales = DiscountSales
        self.Division = Division
        self.Email = Email
        self.EndDate = EndDate
        self.EstablishedDate = EstablishedDate
        self.Fax = Fax
        self.GLAccountPurchase = GLAccountPurchase
        self.GLAccountSales = GLAccountSales
        self.GLAP = GLAP
        self.GLAR = GLAR
        self.GlnNumber = GlnNumber
        self.HasWithholdingTaxSales = HasWithholdingTaxSales
        self.ignoreDatevWarningMessage = ignoreDatevWarningMessage
        self.IntraStatArea = IntraStatArea
        self.IntraStatDeliveryTerm = IntraStatDeliveryTerm
        self.IntraStatTransactionA = IntraStatTransactionA
        self.IntraStatTractionB = IntraStatTractionB
        self.IntraStatTransporterMethod = IntraStatTransporterMethod
        self.InvoiceAccount = InvoiceAccount
        self.InvoiceAccountCode = InvoiceAccountCode
        self.InvoiceAccountName = InvoiceAccountName
        self.InvoiceAttachmentType = InvoiceAttachmentType
        self.InvoicingMethod = InvoicingMethod
        self.IsAccountant = IsAccountant
        self.IsAgency = IsAgency
        self.IsAnonymised = IsAnonymised
        self.IsCompetitor = IsCompetitor
        self.IsExtraDuty = IsExtraDuty
        self.IsMailing = IsMailing
        self.IsPilot = IsPilot
        self.IsReseller = IsReseller
        self.IsSales = IsSales
        self.IsSupplier = IsSupplier
        self.Language = Language
        self.LanguageDescription = LanguageDescription
        self.Latitude = Latitude
        self.LeadPurpose = LeadPurpose
        self.LeadSource = LeadSource
        self.Logo = Logo
        self.LogoFileName = LogoFileName
        self.LogoThumbnailUrl = LogoThumbnailUrl
        self.LogoUrl = LogoUrl
        self.Longitude = Longitude
        self.MainContact = MainContact
        self.Modified = Modified
        self.Modifier = Modifier
        self.ModifierFullName = ModifierFullName
        self.Name = Name
        self.OINNumber = OINNumber
        self.Parent = Parent
        self.PayAsYouEarn = PayAsYouEarn
        self.PaymentConditionPurchase = PaymentConditionPurchase
        self.PaymentConditionPurchaseDescription = PaymentConditionPurchaseDescription
        self.PaymentConditionSales = PaymentConditionSales
        self.PaymentConditionSalesDescription = PaymentConditionSalesDescription
        self.Phone = Phone
        self.PhoneExtension = PhoneExtension
        self.Postcode = Postcode
        self.PriceList = PriceList
        self.PurchaseCurrency = PurchaseCurrency
        self.PurchaseCurrencyDescription = PurchaseCurrencyDescription
        self.PurchaseLeadDays = PurchaseLeadDays
        self.PurchaseVATCode = PurchaseVATCode
        self.PurchaseVATCodeDescription = PurchaseVATCodeDescription
        self.RecepientOfCommissions = RecepientOfCommissions
        self.Remarks = Remarks
        self.Reseller = Reseller
        self.ResellerCode = ResellerCode
        self.ResellerName = ResellerName
        self.RSIN = RSIN
        self.SalesCurrency = SalesCurrency
        self.SalesCurrencyDescription = SalesCurrencyDescription
        self.SalesVATCode = SalesVATCode
        self.SalesVATCodeDescription = SalesVATCodeDescription
        self.SearchCode = SearchCode
        self.SecurityLevel = SecurityLevel
        self.SeperateInvPerSubscription = SeperateInvPerSubscription
        self.ShippingLeadDays = ShippingLeadDays
        self.ShippingMethod = ShippingMethod
        self.ShowRemarkForSales = ShowRemarkForSales
        self.StartDate = StartDate
        self.State = State
        self.StateName = StateName
        self.Status = Status
        self.StatusSince = StatusSince
        self.TradeName = TradeName
        self.Type = Type
        self.UniqueTaxpayerReference = UniqueTaxpayerReference
        self.VATLiability = VATLiability
        self.VATNumber = VATNumber
        self.Website = Website